@@ -1,3 +1,6 @@
+#Versión
+__version__ = "0.0.25"
+
 #Funciones
 from . import eo
 from . import fv
@@ -14,9 +17,7 @@ from .cl_ReporteBase import *       # Derivada de la clase cl_ApiCammesa. Agrega
 from .cl_PPO import *               # Derivada de la clase cl_ReporteBase. Simplemente tiene configuraciones "listas para" consultar los reportes PPO diarios de CAMMESA
 from .cl_DTE import *               # Derivada de la clase cl_ReporteBase. Simplemente tiene configuraciones "listas para" consultar los reportes DTE mensuales de CAMMESA
 
-from .cl_TablasVC import *
-from .cl_DatosCROM import *
 from .cl_SQLConnector import *
-
-#Versión
-__version__ = "0.0.24"
\ No newline at end of file
+from .cl_TablasVC import *          # Deriva de cl_SQLConnector, permite interactuar con la BD del CROM, de forma simplificada.
+from .cl_DatosCROM import *         # Deriva de cl_TablasVC, permite integrar incidencias y datos 10 segundales alojados en la nube de BLC
+from .cl_DatosCdO import *          # Clase independiente. Interactúa con la API de InAccess para recuperar datos SCADA.
\ No newline at end of file
