@@ -1,36 +1,25 @@
 import datetime as __dt
 
-__formatos_default_fecha = [
-    '%Y-%m-%d',
-    '%d/%m/%y',
-    '%d/%m/%Y',
-    '%d-%m-%y',
-    '%d-%m-%Y',
-    '%d.%m.%y',
-    '%d.%m.%Y',
-    '%d%m%y',
-    '%d%m%Y',
-    '%y-%m-%d',
-    ]
+__conectores = [' ','T']
+
+__separadores_fecha = ['-', '.', '/', ' ', '']
+__separadores_hora = ['-', '.', ':', ' ', '']
+
+__generadores_fecha = [lambda s:f'%Y{s}%m{s}%d', lambda s:f'%d{s}%m{s}%Y', lambda s:f'%d{s}%m{s}%y' ]
+__generadores_horas = [lambda s: f'%H{s}%M{s}%S',lambda s: f'%H{s}%M']
+
+__formatos_default_fecha = [f(s) for f in __generadores_fecha for s in __separadores_fecha]
+__formatos_default_hora = [f(s) for f in __generadores_horas for s in __separadores_hora]
+__formatos_default_fecha_hora = [f+c+h for f in __formatos_default_fecha for c in __conectores for h in __formatos_default_hora]
 
 __formatos_default_periodo = [
-    '%Y-%m',
-    '%y-%m',
-    '%Y.%m',
-    '%y.%m',
-    '%Y%m',
-    '%y%m',
-    '%Y-%m-%d',
-    '%d/%m/%y',
-    '%d/%m/%Y',
-    '%d-%m-%y',
-    '%d-%m-%Y',
-    '%d.%m.%y',
-    '%d.%m.%Y',
-    '%d%m%y',
-    '%d%m%Y',
-    '%y-%m-%d'
-    ] 
+    '%Y-%m','%y-%m','%Y.%m',
+    '%y.%m','%Y%m','%y%m',
+    '%Y-%m-%d','%d/%m/%y',
+    '%d/%m/%Y','%d-%m-%y',
+    '%d-%m-%Y','%d.%m.%y',
+    '%d.%m.%Y','%d%m%y',
+    '%d%m%Y','%y-%m-%d',] 
 
 def hora_op(fecha,prevenir_futuro=False):
     fecha = validar_fecha(fecha,prevenir_futuro=prevenir_futuro)
@@ -234,19 +223,12 @@ def iterar_mensual(ts_ini,ts_fin,formatos=__formatos_default_fecha,prevenir_futu
         
         ts_loop = sumar_mes(ts_loop)
 
-def _procesar_formato(fecha,formato):
-    try:
-        return __dt.datetime.strptime(fecha,formato)
-    except ValueError:
-        return None
-
 def _procesar_formatos(fecha,formatos):
-
     for formato in formatos:
-        fecha_formateada = _procesar_formato(fecha,formato)
-        if fecha_formateada != None:
-            return fecha_formateada
-        
+        try:
+            return __dt.datetime.strptime(fecha,formato)
+        except:
+            continue
     raise ValueError('Formato de fecha no reconocido.')
 
 def input_fecha(nombre='',formatos=__formatos_default_fecha,prevenir_futuro=False):
@@ -306,3 +288,27 @@ def validar_fechas(fecha_ini,fecha_fin,formatos=__formatos_default_fecha,preveni
     fecha_ini, fecha_fin = sorted([fecha_ini,fecha_fin])
     
     return fecha_ini, fecha_fin
+
+def validar_fecha_hora(fecha,formatos=__formatos_default_fecha_hora,prevenir_futuro=True):
+    '''Compara la fecha ingresada vs la fecha actual del sistema.
+    Elije el valor más pequeño entre ambas. Es decir, no permite fechas futuras por defecto.'''
+    if isinstance(fecha,str):
+        try:
+            fecha = _procesar_formatos(fecha,formatos)
+        except:
+            fecha = validar_fecha(fecha,prevenir_futuro=prevenir_futuro)
+            
+    elif isinstance(fecha,__dt.datetime):
+        pass
+    
+    else:
+        raise ValueError('La variable "fecha" debe ser del tipo String o datetime.datetime')
+    
+    if prevenir_futuro:
+        ahora = __dt.datetime.now()
+        intervalo_10min = (ahora.minute // 10)  * 10
+        ahora = ahora.replace(minute=intervalo_10min, second=0) - __dt.timedelta(minutes=10)
+        
+        return min(ahora, fecha)
+    else:
+        return fecha
\ No newline at end of file
